@@ -14,6 +14,14 @@
 
 namespace boost{ namespace math{ namespace detail{
 
+//
+// These need forward declaring to keep GCC happy:
+//
+template <class T, class Policy, class Lanczos>
+T gamma_imp(T z, const Policy& pol, const Lanczos& l);
+template <class T, class Policy>
+T gamma_imp(T z, const Policy& pol, const lanczos::undefined_lanczos& l);
+
 //
 // lgamma for small arguments:
 //
